@@ -1,7 +1,7 @@
 /*
 
-    xpuyopuyo - pai.c         Copyright(c) 1999 Justin Smith
-    justins@chaos2.org        http://chaos2.org/
+    xpuyopuyo - pai.c         Copyright(c) 1999-2003 Justin David Smith
+    justins(at)chaos2.org     http://chaos2.org/
     
     Computer AI Code (revision 1, the stupid rule-based AI's)
     
@@ -26,6 +26,7 @@
 #include <xpuyopuyo.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <config.h>
 #include <pai.h>
 #include <pmanip.h>
@@ -794,7 +795,7 @@ void p_ai_mutate(const aiinfo *ai, airule *d_, const airule *s_, /* TEMP int n,
 #endif /* Breeding? */
    
 
-inline const char *p_ai_get_name(const airule *a_) {
+const char *p_ai_get_name(const airule *a_) {
 /* p_ai_get_name */
 
    return(((airule_int *)a_)->name);
@@ -802,7 +803,7 @@ inline const char *p_ai_get_name(const airule *a_) {
 }
 
 
-inline const char *p_ai_get_desc(const airule *a_) {
+const char *p_ai_get_desc(const airule *a_) {
 /* p_ai_get_desc */
 
    return(((airule_int *)a_)->desc);
@@ -810,7 +811,7 @@ inline const char *p_ai_get_desc(const airule *a_) {
 }
 
 
-inline int p_ai_get_score(const airule *a_) {
+int p_ai_get_score(const airule *a_) {
 /* p_ai_get_score */
 
    return(((airule_int *)a_)->score);
@@ -818,7 +819,7 @@ inline int p_ai_get_score(const airule *a_) {
 }
 
 
-inline int p_ai_get_index(const airule *a_) {
+int p_ai_get_index(const airule *a_) {
 /* p_ai_get_index */
 
    return(((airule_int *)a_)->index);
@@ -826,7 +827,7 @@ inline int p_ai_get_index(const airule *a_) {
 }
 
 
-inline const char *p_ai_name_of(const aiinfo *ai_, int rule) {
+const char *p_ai_name_of(const aiinfo *ai_, int rule) {
 /* p_ai_name_of */
 
    if(rule < 0) return("Random AI"); 
@@ -835,7 +836,7 @@ inline const char *p_ai_name_of(const aiinfo *ai_, int rule) {
 }
 
 
-inline const char *p_ai_desc_of(const aiinfo *ai_, int rule) {
+const char *p_ai_desc_of(const aiinfo *ai_, int rule) {
 /* p_ai_desc_of */
 
    if(rule < 0) return("Randomly selected AI rule"); 
