@@ -1,7 +1,7 @@
 /*
 
-    xpuyopuyo - pai.h         Copyright(c) 1999 Justin Smith
-    justins@chaos2.org        http://chaos2.org/
+    xpuyopuyo - pai.h         Copyright(c) 1999-2003 Justin Smith
+    justins(at)chaos2.org     http://chaos2.org/
     
     Header for AI
     
