@@ -426,6 +426,10 @@ static void p_game_advance_drop(pconfig *c, pplayer *p, int speed) {
    /* Check for a collision with the ground or other pieces */
    if(p_piece_fall_collide(f)) {
       /* Piece is down! */
+      #if USE_SOUND
+         /* Piece landed */
+         p_sound_play_effect(c->sound, P_SOUND_PLOP, p->number);
+      #endif
       p_manip_lock(f);
       p_field_clear(f->piece);
       p_game_set_state(p, P_STATE_MATCH_FALL, P_FALL_TIME);
@@ -460,6 +464,10 @@ static void p_game_advance_state_network(pconfig *c, pplayer *p) {
       switch(res) {
       case P_NET_RES_LOST:
          /* This player just lost the game */
+         #if USE_SOUND
+            /* Player died */
+            p_sound_play_effect(c->sound, P_SOUND_DEATH, p->number);
+         #endif
          f = p->field;
          p_field_redraw_all(f);
          p_game_set_state(p, P_STATE_LOSER_, P_DRAIN_TIME);
@@ -564,6 +572,11 @@ static void p_game_advance_state_idle(pconfig *c, pplayer *p) {
       p_field_redraw_all(f);
       p_game_set_state(p, P_STATE_LOSER_, P_TOURNAMENT_HYPER(c) ? 0 : P_DRAIN_TIME);
 
+      #if USE_SOUND
+         /* Player died */
+         p_sound_play_effect(c->sound, P_SOUND_DEATH, p->number);
+      #endif
+
       #if USE_NETWORK
          /* Tell opponent about our gruesome defeat */
          if(P_NETWORK(c)) {
@@ -725,6 +738,12 @@ static void p_game_advance_state_rocks(pconfig *c, pplayer *p) {
 
          /* Now, we need to drop all those rocks */
          p_game_set_state(p, P_STATE_ROCKS_FALL, P_TOURNAMENT_HYPER(c) ? 0 : P_FALL_TIME);
+
+         #if USE_SOUND
+            /* Got some rocks */
+            p_sound_play_effect(c->sound, P_SOUND_AGONY_2, p->number);
+         #endif
+
       } /* Did we kill the player with rocks? */
 
    } else {
@@ -769,6 +788,11 @@ static void p_game_advance_state_matching(pconfig *c, pplayer *p) {
    j = p_manip_explode_matches(p->field, c->fieldmatch);
    if(j) {
 
+      #if USE_SOUND
+         /* Got a match */
+         p_sound_play_effect(c->sound, P_SOUND_BWOAP, p->number);
+      #endif
+
       /* Some matches were exploded; continue */
       p->num_at_once += j;
       p_game_set_state(p, P_STATE_MATCHING_2, P_TOURNAMENT_HYPER(c) ? 0 : P_EXPL_TIME);
