@@ -1,7 +1,7 @@
 /*
 
-    xpuyopuyo - pgraph-gtk.h     Copyright(c) 1999,2000 Justin David Smith
-    justins@chaos2.org           http://chaos2.org/
+    xpuyopuyo - pgraph-gtk.h     Copyright(c) 1999-2003 Justin David Smith
+    justins(at)chaos2.org        http://chaos2.org/
 
 
     This program is free software; you can redistribute it and/or modify
