@@ -43,7 +43,7 @@
 
 
 
-inline gint pixmap_width(GdkPixmap *p) {
+gint pixmap_width(GdkPixmap *p) {
 /* pixmap_width */
 
    gint width;
@@ -55,7 +55,7 @@ inline gint pixmap_width(GdkPixmap *p) {
 }
 
 
-inline gint pixmap_height(GdkPixmap *p) {
+gint pixmap_height(GdkPixmap *p) {
 /* pixmap_height */
 
    gint height;
@@ -570,7 +570,7 @@ static inline void p_window_put_image_to(const pwindow_gtk *w, GdkDrawable* dest
 }
 
 
-inline void p_window_put_image(const pwindow_gtk *w, GdkPixmap *pix, GdkBitmap* mask, int dx, int dy) {
+void p_window_put_image(const pwindow_gtk *w, GdkPixmap *pix, GdkBitmap* mask, int dx, int dy) {
 
    p_window_put_subimage(w, pix, mask, 0, 0, dx, dy, pixmap_width(pix), pixmap_height(pix));
 
